use bananas2;

CREATE TABLE accountheading (
  id int(11) NOT NULL auto_increment,
  parentid int(11) NOT NULL default '0',
  name varchar(128) NOT NULL default '',
  sref int(11) NOT NULL default '0',
  eref int(11) NOT NULL default '0',
  gref int(11) NOT NULL default '0',
  type int(1) NOT NULL default '0',
  guitypeid int(11) NOT NULL default '0',
  PRIMARY KEY(id,parentid),
  CONSTRAINT accountheading_parent_fk FOREIGN KEY(parentid) REFERENCES accountheading(id) 
  ON UPDATE CASCADE
  ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE account (
  id int(11) NOT NULL auto_increment,
  parentid int(11) NOT NULL default '0',
  headingid int(11) NOT NULL default '0',
  accountnumber varchar(32) NOT NULL default '',
  name varchar(128) NOT NULL default '',
  gref int(11) NOT NULL default '0',
  profitloss char(1) NOT NULL default 'N',
  PRIMARY KEY  (id,parentid,headingid),
  KEY accountnumber (accountnumber),
  KEY profitloss (profitloss),
  CONSTRAINT account_parent_fk FOREIGN KEY(parentid) REFERENCES account(id),
  CONSTRAINT account_heading_fk FOREIGN KEY(headingid) REFERENCES accountheading(id)
) ENGINE=InnoDB; 

CREATE TABLE address (
  id int(11) NOT NULL auto_increment,
  addressid int(11) NOT NULL default '0',
  typeid tinyint(4) NOT NULL default '0',
  address1 varchar(128) NOT NULL default '',
  address2 varchar(128) NOT NULL default '',
  address3 varchar(128) NOT NULL default '',
  city varchar(64) NOT NULL default '',
  state varchar(32) NOT NULL default '',
  postcode varchar(32) NOT NULL default '',
  countryid smallint(4) NOT NULL default '0',
  PRIMARY KEY (id,addressid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE addresstype (
  id int(11) NOT NULL auto_increment,
  name varchar(32) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE adjustment (
  id int(11) NOT NULL auto_increment,
  name varchar(64) NOT NULL default '',
  enteredat timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  stationid varchar(20) NOT NULL default '',
  userid int(11) NOT NULL default '0',
  typeid int(11) NOT NULL default '0',
  amount double NOT NULL default '0',
  `data` varchar(255) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE adjustmenttype (
  id int(11) NOT NULL auto_increment,
  name varchar(64) NOT NULL default '',
  active char(1) NOT NULL default 'N',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE applicant (
  id int(11) NOT NULL auto_increment,
  appliedon timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  titleid tinyint(4) NOT NULL default '0',
  firstname varchar(32) NOT NULL default '',
  lastname varchar(32) NOT NULL default '',
  middleinitial char(1) NOT NULL default '',
  prevsurname varchar(32) NOT NULL default '',
  dob date NOT NULL default '0000-00-00',
  gender char(1) NOT NULL default '',
  occupation varchar(32) NOT NULL default '',
  houseno varchar(100) NOT NULL default '',
  street1 varchar(32) NOT NULL default '',
  street2 varchar(32) NOT NULL default '',
  street3 varchar(32) NOT NULL default '',
  district varchar(32) NOT NULL default '',
  city varchar(32) NOT NULL default '',
  state varchar(32) NOT NULL default '',
  postcode varchar(16) NOT NULL default '',
  countryid tinyint(4) NOT NULL default '0',
  phonehome varchar(16) NOT NULL default '',
  phonework varchar(16) NOT NULL default '',
  phonemobile varchar(16) NOT NULL default '',
  fax varchar(16) NOT NULL default '',
  emailhome varchar(32) NOT NULL default '',
  emailwork varchar(32) NOT NULL default '',
  memo varchar(255) NOT NULL default '',
  email varchar(64) NOT NULL default '',
  login varchar(16) NOT NULL default '',
  `password` varchar(16) NOT NULL default '',
  subscribeid tinyint(4) NOT NULL default '0',
  proposedid int(11) NOT NULL default '0',
  secondedid int(11) NOT NULL default '0',
  nominatedid int(11) NOT NULL default '0',
  approved char(1) NOT NULL default '',
  approvedon timestamp NOT NULL default '0000-00-00 00:00:00',
  PRIMARY KEY  (id),
  KEY lastname (lastname,city)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE area (
  id int(11) NOT NULL auto_increment,
  parentid tinyint(4) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  description varchar(64) NOT NULL default '',
  refid int(11) NOT NULL default '0',
  reftype tinyint(4) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE authority (
  id int(11) NOT NULL auto_increment,
  name varchar(64) NOT NULL default '',
  description varchar(255) NOT NULL default '',
  perm_login char(1) NOT NULL default 'N',
  perm_list char(1) NOT NULL default 'N',
  perm_browse char(1) NOT NULL default 'N',
  perm_add char(1) NOT NULL default 'N',
  perm_edit char(1) NOT NULL default 'N',
  perm_delete char(1) NOT NULL default 'N',
  perm_shutdown char(1) NOT NULL default 'N',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE badcheque (
  id int(11) NOT NULL auto_increment,
  chequeid int(11) NOT NULL default '0',
  addedby int(11) NOT NULL default '0',
  addeddate date NOT NULL default '0000-00-00',
  name varchar(128) NOT NULL default '',
  chequestart varchar(32) NOT NULL default '',
  chequeend varchar(32) NOT NULL default '',
  bankdata varchar(128) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE bankdetails (
  id int(11) NOT NULL auto_increment,
  bankid int(11) NOT NULL default '0',
  accountid int(11) NOT NULL default '0',
  name varchar(64) NOT NULL default '',
  branch varchar(64) NOT NULL default '',
  addressid int(11) NOT NULL default '0',
  contactid int(11) NOT NULL default '0',
  banksortcode varchar(32) NOT NULL default '',
  banknumber varchar(32) NOT NULL default '',
  PRIMARY KEY(id,bankid),
  KEY account_id (accountid),
  KEY bankaccountnumber (banknumber)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE bankaccount (
  id int(11) NOT NULL auto_increment,
  bankid int(11) NOT NULL default '0',
  name varchar(64) NOT NULL default '',
  number varchar(64) NOT NULL default '',
  PRIMARY KEY (id,bankid),
  KEY accountnumber (number),
  CONSTRAINT bankaccount_bank_fk FOREIGN KEY(bankid) REFERENCES bankdetails(id)
  ON UPDATE CASCADE
  ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE bankitem (
  id int(11) NOT NULL auto_increment,
  bankid int(11) NOT NULL default '0',
  itemdate date NOT NULL default '0000-00-00',
  itemtype int(11) NOT NULL default '0',
  ledgerentryid int(11) NOT NULL default '0',
  transid int(11) NOT NULL default '0',
  referencedata varchar(32) NOT NULL default '',
  amount double NOT NULL default '0',
  PRIMARY KEY(id,bankid),
  KEY bankitemdate (itemdate),
  KEY bankitemaccountid (ledgerentryid),
  CONSTRAINT bankitem_bank_fk FOREIGN KEY(bankid) REFERENCES bankaccount(id)
  ON UPDATE CASCADE
  ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE bankitemtype (
  id int(11) NOT NULL auto_increment,
  name varchar(64) NOT NULL default '',
  debit char(1) NOT NULL default 'N',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE bom (
  id int(11) NOT NULL auto_increment,
  cmid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  description varchar(64) NOT NULL default '',
  typeid tinyint(4) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE bomitem (
  id int(11) NOT NULL auto_increment,
  bomid int(11) NOT NULL default '0',
  productid int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE bqname (
  id int(11) NOT NULL auto_increment,
  name varchar(64) NOT NULL default '',
  accountid int(11) NOT NULL default '0',
  onmenu char(1) NOT NULL default 'N',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE category (
  id int(11) NOT NULL auto_increment,
  parentid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  description varchar(128) NOT NULL default '',
  eonsite char(1) NOT NULL default 'N',
  PRIMARY KEY(id,parentid),
  CONSTRAINT category_parent_fk FOREIGN KEY(parentid) REFERENCES category(id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE chargeaccount (
  id int(11) NOT NULL auto_increment,
  chargeid int(11) NOT NULL default '0',
  typeid tinyint(4) NOT NULL default '0',
  cmid int(11) NOT NULL default '0',
  bankid int(11) NOT NULL default '0',
  creditlimit float(6,2) NOT NULL default '0.00',
  lasttransaction date NOT NULL default '0000-00-00',
  accountid varchar(32) NOT NULL default '0',
  standardterms char(1) NOT NULL default 'N',
  codterms char(1) NOT NULL default 'N',
  prepaidterms char(1) NOT NULL default 'N',
  termstype char(1) NOT NULL default 'N',
  duemonthend char(1) NOT NULL default 'N',
  duedays int(3) NOT NULL default '0',
  discountdays int(3) NOT NULL default '0',
  discountid int(11) NOT NULL default '0',
  notes varchar(255) NOT NULL default '',
  PRIMARY KEY(id,chargeid),
  INDEX(bankid),
  CONSTRAINT chargeaccount_bank_fk FOREIGN KEY(bankid) REFERENCES bankaccount(id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE chargeacctype (
  id int(11) NOT NULL auto_increment,
  name varchar(32) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE chargeitem (
  id int(11) NOT NULL auto_increment,
  chargeaccountid int(11) NOT NULL default '0',
  targetid int(11) NOT NULL default '0',
  transid int(11) NOT NULL default '0',
  enteredat timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  amount double NOT NULL default '0',
  PRIMARY KEY(id,chargeaccountid),
  CONSTRAINT chargeitem_chargeaccount_fk FOREIGN KEY(chargeaccountid) REFERENCES chargeaccount(id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE class (
  id int(11) NOT NULL auto_increment,
  classid int(11) NOT NULL default '0',
  empid int(11) NOT NULL default '0',
  sdate date NOT NULL default '0000-00-00',
  edate date NOT NULL default '0000-00-00',
  minnumber int(11) NOT NULL default '1',
  maxnumber int(11) NOT NULL default '1',
  name varchar(64) NOT NULL default '',
  description varchar(255) NOT NULL default '',
  restrictions varchar(255) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE collection (
  id int(11) NOT NULL auto_increment,
  name varchar(32) NOT NULL default '',
  description varchar(64) NOT NULL default '',
  collectionid int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE commission (
  id int(11) NOT NULL auto_increment,
  commissionid int(11) NOT NULL default '0',
  rate float NOT NULL default '0',
  break float NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE company (
  id int(11) NOT NULL auto_increment,
  attributeid int(11) NOT NULL default '0',
  tradingname varchar(64) NOT NULL default '',
  companyname varchar(64) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE companyattribute (
  id int(11) NOT NULL auto_increment,
  attributeid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  `type` int(2) NOT NULL default '0',
  format varchar(255) NOT NULL default '',
  mask varchar(255) NOT NULL default '',
  `value` varchar(255) NOT NULL default '',
  PRIMARY KEY  (id),
  KEY attributeid (attributeid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE businessunit (
  id INT NOT NULL AUTO_INCREMENT ,
  companyid INT NOT NULL ,
  attributeid INT NOT NULL ,
  name VARCHAR(64) NOT NULL ,
  PRIMARY KEY (id,companyid,attributeid),
  CONSTRAINT businessunit_company_fk FOREIGN KEY(companyid) REFERENCES company(id)
) TYPE = InnoDB;

CREATE TABLE ebcpa (
  id int(11) NOT NULL auto_increment,
  parentid INT NOT NULL,
  attributeid INT NOT NULL,
  method varchar(64) NOT NULL default '',
  value varchar(255) NOT NULL default '',
  PRIMARY KEY(id,parentid,attributeid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE ebattribute (
  id int(11) NOT NULL auto_increment,
  attributeid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  `type` int(2) NOT NULL default '0',
  format varchar(255) NOT NULL default '',
  mask varchar(255) NOT NULL default '',
  `value` varchar(255) NOT NULL default '',
  PRIMARY KEY  (id),
  KEY attributeid (attributeid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--contacts

CREATE TABLE contactattribute (
  id int(11) NOT NULL auto_increment,
  attributeid int(11) NOT NULL default '0',
  parentid int(4) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  `type` int(2) NOT NULL default '0',
  encoding int(2) NOT NULL default '0',
  format varchar(255) NOT NULL default '',
  mask varchar(255) NOT NULL default '',
  `value` varchar(255) NOT NULL default '',
  PRIMARY KEY(id, attributeid, parentid)
) ENGINE=InnoDB;
--CONSTRAINT contactattribute_parent_fk FOREIGN KEY(parentid) REFERENCES contactattribute(id) 
--CONSTRAINT contactattribute_contact_fk FOREIGN KEY(attributeid) REFERENCES contact(attributeid)
--ON UPDATE CASCADE
--ON DELETE CASCADE
  
CREATE TABLE contactdetails (
  id int(11) NOT NULL auto_increment,
  contactdetailsid int(11) NOT NULL default '0',
  typeid int(11) NOT NULL default '0',
  data varchar(255) NOT NULL default '0',
  PRIMARY KEY(id, contactdetailsid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE contacts (
  id int(11) NOT NULL auto_increment,
  contactid int(11) NOT NULL default '0',
  attributeid int(11) NOT NULL default '0',
  contactdetailsid int(11) NOT NULL default '0',
  ownerid int(11) NOT NULL default '0',
  addressid int(11) NOT NULL default '0',
  imageid int(11) NOT NULL default '0',
  titleid tinyint(4) NOT NULL default '0',
  firstname varchar(32) NOT NULL default 'No Name',
  lastname varchar(64) NOT NULL default 'No Name',
  givenname varchar(64) NOT NULL default '',
  middleinitial char(1) NOT NULL default '',
  suffix varchar(16) NOT NULL default '',
  birthdate date NOT NULL default '0000-00-00',
  lastcontact date NOT NULL default '0000-00-00',
  timezone tinyint(4) NOT NULL default '0',
  private char(1) NOT NULL default 'A',
  memoid int(11) NOT NULL default '0',
  PRIMARY KEY(id,contactid,attributeid,contactdetailsid),
  INDEX(addressid),
  INDEX(imageid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
--CONSTRAINT contacts_address_fk FOREIGN KEY(addressid) REFERENCES address(id),
--CONSTRAINT contacts_details_fk FOREIGN KEY(contactdetailsid) REFERENCES contactdetails(id)

CREATE TABLE contacttype (
  id int(11) NOT NULL auto_increment,
  name varchar(32) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE contract (
  id int(11) NOT NULL auto_increment,
  tid int(11) NOT NULL default '0',
  siteid int(11) NOT NULL default '0',
  statusid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  description text NOT NULL,
  type char(1) NOT NULL default 'S',
  PRIMARY KEY(id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE country (
  id smallint(6) NOT NULL auto_increment,
  name char(64) NOT NULL default '',
  isoname char(4) NOT NULL default '',
  smallisoname char(2) NOT NULL default '',
  addressformat tinyint(4) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE course (
  id int(11) NOT NULL auto_increment,
  courseid int(11) NOT NULL default '0',
  sdate date NOT NULL default '0000-00-00',
  edate date NOT NULL default '0000-00-00',
  minnumber int(11) NOT NULL default '1',
  maxnumber int(11) NOT NULL default '1',
  name varchar(64) NOT NULL default '',
  description varchar(255) NOT NULL default '',
  restrictions varchar(255) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE createmod (
  id int(11) NOT NULL auto_increment,
  creationdate date NOT NULL default '0000-00-00',
  modifieddate date NOT NULL default '0000-00-00',
  createdby int(11) NOT NULL default '0',
  modifiedby int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE currency (
  id smallint(6) NOT NULL auto_increment,
  countryid smallint(6) NOT NULL default '0',
  bigname char(32) NOT NULL default '',
  isoname char(4) NOT NULL default '',
  isonumber smallint(6) NOT NULL default '0',
  monetaryunitsid int(4) NOT NULL default '1',
  smallname char(32) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE custcallhistory (
  id int(11) NOT NULL auto_increment,
  custid int(11) NOT NULL default '0',
  cdate date NOT NULL default '0000-00-00',
  caller char(64) NOT NULL default '',
  `subject` char(64) default NULL,
  details char(64) default NULL,
  actionid int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE custflags (
  id int(11) NOT NULL auto_increment,
  custid int(11) NOT NULL default '0',
  edate date NOT NULL default '0000-00-00',
  notes varchar(255) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE custhistory (
  id int(11) NOT NULL auto_increment,
  custid int(11) NOT NULL default '0',
  transid int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE custinterventionhistory (
  id int(11) NOT NULL auto_increment,
  custid int(11) NOT NULL default '0',
  contactwhoid int(11) NOT NULL default '0',
  contacttime timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  outtime timestamp NOT NULL default '0000-00-00 00:00:00',
  arrivetime timestamp NOT NULL default '0000-00-00 00:00:00',
  leavetime timestamp NOT NULL default '0000-00-00 00:00:00',
  cause varchar(64) NOT NULL default '',
  cure varchar(64) NOT NULL default '',
  billed char(1) NOT NULL default 'N',
  interventistid int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE customer (
  id int(11) NOT NULL auto_increment,
  cmid int(11) NOT NULL default '0',
  contactid int(11) NOT NULL default '0',
  storecardid int(11) NOT NULL default '0',
  loyalityid int(11) NOT NULL default '0',
  signatureid int(11) NOT NULL default '0',
  chargeaccountid int(11) NOT NULL default '0',
  login varchar(100) NOT NULL default '',
  `password` varchar(16) NOT NULL default '',
  attributesid int(11) NOT NULL default '0',
  enabled char(1) NOT NULL default 'N',
  memoid int(11) NOT NULL default '0',
  PRIMARY KEY  (id),
  INDEX(contactid),
  INDEX(chargeaccountid),
  INDEX(attributesid),
  CONSTRAINT customer_contact_fk FOREIGN KEY(contactid) REFERENCES contacts(id),
  CONSTRAINT customer_charge_fk FOREIGN KEY(chargeaccountid) REFERENCES chargeaccount(id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
--CONSTRAINT customer_loyaltyid_fk FOREIGN KEY(loyalityid) REFERENCES loyalty(id)

CREATE TABLE customerattribute (
  id int(11) NOT NULL auto_increment,
  attributeid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  `type` int(2) NOT NULL default '0',
  format varchar(255) NOT NULL default '',
  mask varchar(255) NOT NULL default '',
  `value` varchar(255) NOT NULL default '',
  PRIMARY KEY  (id),
  KEY attributeid (attributeid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE customerlog (
  id int(11) NOT NULL auto_increment,
  customerid int(11) NOT NULL default '0',
  actionid tinyint(4) NOT NULL default '0',
  stamper timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  `data` varchar(32) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE loyalty (
  id int(11) NOT NULL auto_increment,
  loyaltyid int(11) NOT NULL default '0',
  pointsid int(11) NOT NULL default '0',
  catalogueid int(11) NOT NULL default '0',
  PRIMARY KEY(id,loyaltyid,pointsid,catalogueid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
--CONSTRAINT loyalty_loyaltyid_fk FOREIGN KEY(loyaltyid) REFERENCES loyalty(id)

CREATE TABLE pointstype (
  id int(11) NOT NULL auto_increment,
  name varchar(32) NOT NULL default '',
  description varchar(64) NOT NULL default '',
  `value` double NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE pointslog (
  id int(11) NOT NULL auto_increment,
  pointsid int(11) NOT NULL default '0',
  pointstypeid int(11) NOT NULL default '0',
  issuedon date NOT NULL default '0000-00-00',
  redeemcode VARCHAR(32) NOT NULL,
  number int(11) NOT NULL default '0',
  redeemed char(1) NOT NULL default 'N',
  PRIMARY KEY(id,pointsid,pointstypeid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE giftcertificate (
  id int(11) NOT NULL auto_increment,
  customerid int(11) NOT NULL default '0',
  issuedon date NOT NULL default '0000-00-00',
  redeemcode VARCHAR(32) NOT NULL,
  value float NOT NULL default '0.0',
  redeemed char(1) NOT NULL default 'N',
  PRIMARY KEY(id,customerid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE dropoff (
  id int(11) NOT NULL auto_increment,
  dropoffid int(11) NOT NULL default '0',
  dropoffnumber varchar(64) NOT NULL default '',
  enteredby int(11) NOT NULL default '0',
  customerid int(11) NOT NULL default '0',
  statusid int(11) NOT NULL default '0',
  dateleft date NOT NULL default '0000-00-00',
  daterequired date NOT NULL default '0000-00-00',
  billeddate date NOT NULL default '0000-00-00',
  pickupdate date NOT NULL default '0000-00-00',
  subtotal float(6,2) NOT NULL default '0.00',
  tax float(6,2) NOT NULL default '0.00',
  total float(6,2) NOT NULL default '0.00',
  basecurrencyid int(4) NOT NULL default '0',
  ledgerentryid int(11) NOT NULL default '0',
  transactionid int(11) NOT NULL default '0',
  PRIMARY KEY(id,dropoffid),
  INDEX(customerid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE dropoffitems (
  id int(11) NOT NULL auto_increment,
  dropoffid int(11) NOT NULL default '0',
  name char(32) NOT NULL default '',
  description char(128) NOT NULL default '',
  quantity int(11) NOT NULL default '1',
  barcode char(16) NOT NULL default '',
  PRIMARY KEY(id,dropoffid),
  CONSTRAINT dropoffitems_dropoff_fk FOREIGN KEY(dropoffid) REFERENCES dropoff(id)
  ON UPDATE CASCADE
  ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE dropoffstatus (
  id int(11) NOT NULL auto_increment,
  name char(32) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE delivery (
  id int(11) NOT NULL auto_increment,
  cmid int(11) NOT NULL default '0',
  delivererid int(11) NOT NULL default '0',
  customerid int(11) NOT NULL default '0',
  transactionid int(11) NOT NULL default '0',
  `status` int(1) NOT NULL default '0',
  amount float NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;


CREATE TABLE sites (
  id int(11) NOT NULL auto_increment,
  siteid int(11) NOT NULL default '0',
  name varchar(64) NOT NULL default '',
  businessunitid int(11) NOT NULL default '0',
  addressid int(11) NOT NULL default '0',
  contactid int(11) NOT NULL default '0',
  localeid int(4) NOT NULL default '0',
  currencyid int(4) NOT NULL default '270',
  bankid int(11) NOT NULL default '0',
  annualbudget float NOT NULL default '0',
  site varchar(255) NOT NULL default '',
  encryption varchar(255) NOT NULL default '',
  login varchar(64) NOT NULL default '',
  `password` varchar(64) NOT NULL default '',
  active char(1) NOT NULL default 'N',
  PRIMARY KEY(id,siteid),
  INDEX (businessunitid),
  INDEX (addressid),
  INDEX (contactid),
  INDEX (bankid),
  CONSTRAINT sites_company_fk FOREIGN KEY (businessunitid) REFERENCES businessunit(id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
--CONSTRAINT sites_address_fk FOREIGN KEY (addressid) REFERENCES address(id),
--CONSTRAINT sites_contact_fk FOREIGN KEY (contactid) REFERENCES contacts(id),
--CONSTRAINT sites_bank_fk FOREIGN KEY (bankid) REFERENCES bankaccount(id)

CREATE TABLE departments (
  id int(11) NOT NULL auto_increment,
  deptid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  siteid int(11) NOT NULL default '0',
  annualbudget float(6,2) NOT NULL default '0.00',
  headid int(11) NOT NULL default '0',
  localeid int(4) NOT NULL default '0',
  currencyid int(4) NOT NULL default '0',
  active char(1) NOT NULL default 'N',
  PRIMARY KEY(id,deptid),
  CONSTRAINT departments_site_fk FOREIGN KEY(siteid) REFERENCES sites(id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE groups (
  id int(11) NOT NULL auto_increment,
  deptid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  localeid int(4) NOT NULL default '0',
  currencyid int(4) NOT NULL default '0',
  active char(1) NOT NULL default 'N',
  PRIMARY KEY(id,deptid),
  CONSTRAINT groups_dept_fk FOREIGN KEY (deptid)REFERENCES departments (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
 
CREATE TABLE deposit (
  id int(11) NOT NULL auto_increment,
  depositid int(11) NOT NULL default '0',
  cmid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  percentage double NOT NULL default '0',
  refundable char(1) NOT NULL default 'N',
  `type` int(1) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE discount (
  id int(11) NOT NULL auto_increment,
  discountid varchar(16) NOT NULL default '',
  `type` int(1) NOT NULL default '0',
  ident int(11) NOT NULL default '0',
  targetid int(11) NOT NULL default '0',
  margin double NOT NULL default '0',
  `status` varchar(64) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE discreetdiscount (
  id int(11) NOT NULL auto_increment,
  transactionid int(11) NOT NULL default '0',
  userid int(11) NOT NULL default '0',
  stationid varchar(20) NOT NULL default '0',
  `type` int(1) NOT NULL default '0',
  plu varchar(16) NOT NULL default '',
  margin float NOT NULL default '1',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE discrepancy (
  id int(11) NOT NULL auto_increment,
  name varchar(64) NOT NULL default '',
  enteredat timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  stationid varchar(20) NOT NULL default '',
  userid int(11) NOT NULL default '0',
  typeid int(11) NOT NULL default '0',
  amount double NOT NULL default '0',
  `data` varchar(255) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE discrepancytype (
  id tinyint(4) NOT NULL auto_increment,
  name varchar(64) NOT NULL default '',
  active char(1) NOT NULL default 'N',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE document (
  id int(11) NOT NULL auto_increment,
  documentid int(11) NOT NULL default '0',
  cmid int(11) NOT NULL default '0',
  `type` int(11) NOT NULL default '0',
  filename varchar(255) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE ephemeral_plu (
  id int(11) NOT NULL auto_increment,
  refid int(11) NOT NULL default '0',
  entryat timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  plu varchar(128) NOT NULL default '',
  plutype int(2) NOT NULL default '0',
  name varchar(64) NOT NULL default 'No Name',
  rectext varchar(64) NOT NULL default '',
  unitprice double NOT NULL default '0',
  discount float NOT NULL default '0',
  tax float NOT NULL default '0',
  `type` varchar(32) NOT NULL default '',
  PRIMARY KEY  (id),
  UNIQUE KEY PLU (plu)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE employee (
  id int(11) NOT NULL auto_increment,
  employeeid int(11) NOT NULL default '0',
  employeenumber varchar(16) NOT NULL default '',
  groupid int(11) NOT NULL default '0',
  contactid int(11) NOT NULL default '0',
  startdate date NOT NULL default '0000-00-00',
  enddate date NOT NULL default '0000-00-00',
  gender char(1) NOT NULL default 'M',
  jobdesc varchar(64) NOT NULL default '',
  payid int(4) NOT NULL default '0',
  annualpay float(6,2) NOT NULL default '0.00',
  holidayentitlementid int(11) NOT NULL default '0',
  holidaytakenid int(11) NOT NULL default '0',
  taxcode varchar(16) NOT NULL default '',
  nicode varchar(16) NOT NULL default '',
  ninumber varchar(16) NOT NULL default '',
  prevtax float(6,2) NOT NULL default '0.00',
  prevpay float(6,2) NOT NULL default '0.00',
  bankid int(11) NOT NULL default '0',
  PRIMARY KEY(id,employeeid),
  INDEX group_idx (groupid),
  INDEX contact_idx (contactid),
  CONSTRAINT employee_group_fk FOREIGN KEY (groupid) REFERENCES groups (id),
  CONSTRAINT employee_contact_fk FOREIGN KEY (contactid) REFERENCES contacts(id)  
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE employeeaction (
  id int(11) NOT NULL auto_increment,
  name char(32) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE employeelog (
  id int(11) NOT NULL auto_increment,
  employeeid int(11) NOT NULL default '0',
  actionid int(2) NOT NULL default '0',
  stamper timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY(id,employeeid),
  CONSTRAINT employeelog_emp_fk FOREIGN KEY(employeeid) REFERENCES employee(id)
  ON UPDATE CASCADE
  ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE genericgroup (
  id int(11) NOT NULL auto_increment,
  parentid int(11) NOT NULL default '0',
  genericgroupid int(11) NOT NULL default '0',
  name varchar(64) NOT NULL default '',
  desciption varchar(255) NOT NULL default '',
  KEY ID(id,parentid,genericgroupid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE genericgroupitem (
  id int(11) NOT NULL auto_increment,
  genericgroupid int(11) NOT NULL default '0',
  tablename varchar(64) NOT NULL default '',
  fieldname varchar(64) NOT NULL default '',
  KEY ID(id,genericgroupid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE errorlog (
  id int(11) NOT NULL auto_increment,
  issuedat timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  issuedfrom varchar(20) NOT NULL default '',
  issuedby int(11) NOT NULL default '0',
  ackedat timestamp NOT NULL default '0000-00-00 00:00:00',
  `type` int(1) NOT NULL default '0',
  ident int(11) NOT NULL default '0',
  error varchar(64) NOT NULL default '',
  KEY ID (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE event (
  id int(11) NOT NULL auto_increment,
  parentid int(11) NOT NULL default '0',
  ownerid int(11) NOT NULL default '0',
  title varchar(64) NOT NULL default '',
  icon varchar(64) NOT NULL default '',
  starts timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  ends timestamp NOT NULL default '0000-00-00 00:00:00',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE exchangerate (
  sourcid tinyint(4) NOT NULL default '0',
  targetid tinyint(4) NOT NULL default '0',
  exchangerate double NOT NULL default '0'
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE faultlog (
  id int(11) NOT NULL auto_increment,
  custid int(11) NOT NULL default '0',
  `date` date NOT NULL default '0000-00-00',
  memo varchar(255) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE gaccref (
  id int(11) NOT NULL auto_increment,
  accountnumber varchar(32) NOT NULL default '0',
  name varchar(128) NOT NULL default '',
  PRIMARY KEY  (id),
  UNIQUE KEY AccountNumber (accountnumber)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE goodstransfer (
  id int(11) NOT NULL auto_increment,
  goodstransferid int(11) NOT NULL default '0',
  cmid int(11) NOT NULL default '0',
  originator int(11) NOT NULL default '0',
  destination int(11) NOT NULL default '0',
  `status` int(1) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- --------------------------------------------------------

-- 
-- Table structure for table `goodstransferitem`
-- 

CREATE TABLE goodstransferitem (
  id int(11) NOT NULL auto_increment,
  goodstransferid int(11) NOT NULL default '0',
  inventoryid int(11) NOT NULL default '0',
  quantity int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;


CREATE TABLE holidayentitlement (
  id int(11) NOT NULL auto_increment,
  holidayentitlement int(11) NOT NULL default '0',
  typeid int(11) NOT NULL default '0',
  numdays float NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE holidaytaken (
  id int(11) NOT NULL auto_increment,
  typeid int(11) NOT NULL default '0',
  startson date NOT NULL default '0000-00-00',
  endson date NOT NULL default '0000-00-00',
  amount float NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE holidaytype (
  id tinyint(4) NOT NULL auto_increment,
  name varchar(32) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE imagedata (
  id int(11) NOT NULL auto_increment,
  imageid int(11) NOT NULL default '0',
  categoryid int(11) NOT NULL default '0',
  name varchar(64) NOT NULL default '',
  `type` int(1) NOT NULL default '0',
  reffile varchar(255) NOT NULL default '',
  width mediumint(9) NOT NULL default '0',
  height int(4) NOT NULL default '0',
  bbp mediumint(9) NOT NULL default '0',
  scale mediumint(9) NOT NULL default '0',
  PRIMARY KEY(id,imageid,categoryid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE interface (
  id int(11) NOT NULL auto_increment,
  name varchar(64) NOT NULL default '',
  description varchar(255) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE inventory (
  id int(11) NOT NULL auto_increment,
  parentid int(11) NOT NULL default '0',
  categoryid int(11) NOT NULL default '0',
  partnumber int(4) unsigned NOT NULL default '0',
  parttype smallint(6) NOT NULL default '0',
  stocklocation varchar(16) NOT NULL default '',
  description varchar(64) NOT NULL default '',
  instock int(11) NOT NULL default '0',
  maxstock int(11) NOT NULL default '0',
  onorder int(11) NOT NULL default '0',
  rolevel int(11) NOT NULL default '0',
  roqty int(11) NOT NULL default '0',
  reservedqty int(11) NOT NULL default '0',
  leadtime int(11) NOT NULL default '0',
  partclassification int(11) NOT NULL default '0',
  buyquantitypriceid int(11) NOT NULL default '0',
  cmid int(11) NOT NULL default '1',
  invlink int(11) NOT NULL default '0',
  PRIMARY KEY(id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE invitemquantitytype (
  id int(11) NOT NULL auto_increment,
  name char(32) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE invpricequantity (
  id int(11) NOT NULL auto_increment,
  invprqid mediumint(9) NOT NULL default '0',
  nameid int(11) NOT NULL default '1',
  quantity double NOT NULL default '1',
  quantitytypeid int(11) NOT NULL default '0',
  udv int(11) NOT NULL default '1',
  price double(14,4) NOT NULL default '0.0000',
  basecurrencyid mediumint(9) NOT NULL default '0',
  supplierid int(11) NOT NULL default '0',
  suppliercode varchar(64) NOT NULL default '',
  ediid int(11) NOT NULL default '0',
  accountid int(11) NOT NULL default '0',
  taxid int(4) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE itemflags (
  id int(11) NOT NULL auto_increment,
  flagid int(11) NOT NULL default '0',
  `type` int(1) NOT NULL default '0',
  `data` varchar(255) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE label (
  id int(11) NOT NULL auto_increment,
  labelid int(11) NOT NULL default '0',
  `type` int(1) NOT NULL default '0',
  name varchar(64) NOT NULL default '',
  xdim int(11) NOT NULL default '0',
  ydim int(11) NOT NULL default '0',
  `data` varchar(255) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE labelsheet (
  id int(11) NOT NULL auto_increment,
  name varchar(32) NOT NULL default '',
  printsheetid int(11) NOT NULL default '0',
  numx tinyint(4) NOT NULL default '0',
  numy tinyint(4) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE layby (
  id int(11) NOT NULL auto_increment,
  orderid int(11) NOT NULL default '0',
  ordernumber varchar(64) NOT NULL default '',
  customerid int(11) NOT NULL default '0',
  transactionid int(11) NOT NULL default '0',
  statusid int(11) NOT NULL default '0',
  dateplaced date NOT NULL default '0000-00-00',
  daterequired date NOT NULL default '0000-00-00',
  total float(6,2) NOT NULL default '0.00',
  paid float(6,2) NOT NULL default '0.00',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- --------------------------------------------------------

-- 
-- Table structure for table `ledger`
-- 

CREATE TABLE ledger (
  id int(11) NOT NULL auto_increment,
  parentid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  description varchar(64) NOT NULL default '',
  PRIMARY KEY(id,parentid),
  CONSTRAINT ledger_parent_fk FOREIGN KEY(parentid) REFERENCES ledger(id) 
  ON UPDATE CASCADE
  ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE ledgerentry (
  id int(11) NOT NULL auto_increment,
  journalid int(1) NOT NULL default '0',
  ledgerid int(11) NOT NULL default '0',
  accountid int(11) NOT NULL default '0',
  entereddate date NOT NULL default '0000-00-00',
  description varchar(64) NOT NULL default '',
  debit char(1) NOT NULL default 'N',
  amount double NOT NULL default '0',
  posted char(1) NOT NULL default 'N',
  referenceid int(11) NOT NULL default '0',
  PRIMARY KEY(id),
  INDEX(journalid),
  INDEX(ledgerid),
  INDEX(accountid),
  CONSTRAINT ledgerentry_ledger_fk FOREIGN KEY(ledgerid) REFERENCES ledger(id) 
  ON UPDATE CASCADE
  ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE ledgerreference (
  id int(11) NOT NULL auto_increment,
  refid int(11) NOT NULL default '0',
  name varchar(64) NOT NULL default '',
  reftable varchar(64) NOT NULL default '',
  reffield varchar(64) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- --------------------------------------------------------

-- 
-- Table structure for table `loginmethod`
-- 

CREATE TABLE loginmethod (
  id int(11) NOT NULL auto_increment,
  litdata int(1) NOT NULL default '0',
  name varchar(64) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE logintypes (
  id int(11) NOT NULL auto_increment,
  loginid int(11) NOT NULL default '0',
  ident varchar(255) NOT NULL default '',
  `data` varchar(255) NOT NULL default '',
  loginmethodid int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE margin (
  id int(11) NOT NULL auto_increment,
  marginid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  margin float NOT NULL default '0',
  productcollid int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE margincollection (
  id int(11) NOT NULL auto_increment,
  margincollid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  `type` int(1) NOT NULL default '0',
  marginid int(11) NOT NULL default '0',
  sitecollid int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE member (
  id int(11) NOT NULL auto_increment,
  customerid int(11) NOT NULL default '0',
  attributeid int(11) NOT NULL default '0',
  scheduleid int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;


CREATE TABLE memo (
  id int(11) NOT NULL auto_increment,
  memoid int(11) NOT NULL default '0',
  cmid int(11) NOT NULL default '0',
  `subject` varchar(64) NOT NULL default '',
  `data` varchar(255) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- --------------------------------------------------------

-- 
-- Table structure for table `menu`
-- 

CREATE TABLE menu (
  id int(11) NOT NULL auto_increment,
  cmid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  description varchar(64) NOT NULL default '',
  areaid tinyint(4) NOT NULL default '0',
  current char(1) NOT NULL default 'N',
  startid int(11) NOT NULL default '0',
  endid int(11) NOT NULL default '0',
  PRIMARY KEY(id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE menuheading (
  id int(11) NOT NULL auto_increment,
  name varchar(64) NOT NULL default '',
  menuid int(11) NOT NULL default '0',
  imageid int(11) NOT NULL default '0',
  sortorder int(2) NOT NULL default '0',
  PRIMARY KEY(id),
  INDEX(menuid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE menuitem (
  id int(11) NOT NULL auto_increment,
  cmid int(11) NOT NULL default '0',
  menuid int(11) NOT NULL default '0',
  menuheadingid int(11) NOT NULL default '0',
  productid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  description varchar(64) NOT NULL default '',
  quantity varchar(32) NOT NULL default '',
  recutext varchar(64) NOT NULL default '',
  unitprice float NOT NULL default '0.0',
  tax float NOT NULL default '0.0',
  imageid int(11) NOT NULL default '0',
  printerid int(11) NOT NULL default '0',
  available char(1) NOT NULL default 'Y',
  PRIMARY KEY(id),
  INDEX(menuheadingid),
  CONSTRAINT menitem_heading_fk FOREIGN KEY(menuheadingid) REFERENCES menuheading(id) 
  ON UPDATE CASCADE
  ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE menuitemoptions (
  id int(11) NOT NULL auto_increment,
  cmid int(11) NOT NULL default '0',
  menuitemid int(11) NOT NULL default '0',
  name varchar(64) NOT NULL default '',
  description varchar(64) NOT NULL default '',
  PRIMARY KEY(id),
  INDEX(menuitemid),
  CONSTRAINT menuitemoptions_menu_fk FOREIGN KEY(menuitemid) REFERENCES menuitem(id) 
  ON UPDATE CASCADE
  ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE menuschedule (
  id int(11) NOT NULL auto_increment,
  menuid int(11) NOT NULL default '0',
  cmid int(11) NOT NULL default '0',
  PRIMARY KEY(id,menuid),
  CONSTRAINT menuschedule_menu_fk FOREIGN KEY(menuid) REFERENCES menu(id) 
  ON UPDATE CASCADE
  ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE monetaryunits (
  id int(4) NOT NULL auto_increment,
  muid int(4) NOT NULL default '0',
  unit smallint(6) NOT NULL default '0',
  `value` float NOT NULL default '0',
  lowamount int(11) NOT NULL default '0',
  highamount int(11) NOT NULL default '0',
  defamount int(11) NOT NULL default '20',
  defround char(1) NOT NULL default 'N',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE monitorlog (
  id int(11) NOT NULL auto_increment,
  monitorid int(11) NOT NULL default '0',
  enteredat timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  `value` double NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE nirates (
  id int(11) NOT NULL auto_increment,
  name char(16) NOT NULL default '',
  employeerate float(6,2) NOT NULL default '0.00',
  employerrate float(6,2) NOT NULL default '0.00',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE orders (
  id int(11) NOT NULL auto_increment,
  orderid int(11) NOT NULL default '0',
  ordernumber varchar(64) NOT NULL default '',
  enteredby int(11) NOT NULL default '0',
  customerid int(11) NOT NULL default '0',
  deliveryaddressid int(11) NOT NULL default '0',
  billingaddressid int(11) NOT NULL default '0',
  statusid int(11) NOT NULL default '0',
  waitonallitems char(1) NOT NULL default 'Y',
  dateplaced date NOT NULL default '0000-00-00',
  daterequired date NOT NULL default '0000-00-00',
  billeddate date NOT NULL default '0000-00-00',
  shippeddate date NOT NULL default '0000-00-00',
  subtotal float(6,2) NOT NULL default '0.00',
  shipcost float(6,2) NOT NULL default '0.00',
  tax float(6,2) NOT NULL default '0.00',
  total float(6,2) NOT NULL default '0.00',
  basecurrencyid int(4) NOT NULL default '0',
  ledgerentryid int(11) NOT NULL default '0',
  transactionid int(11) NOT NULL default '0',
  shippingid int(11) NOT NULL default '0',
  PRIMARY KEY(id,orderid),
  INDEX(customerid),
  CONSTRAINT orders_customer_fk FOREIGN KEY(customerid) REFERENCES customer(id)
  ON UPDATE CASCADE
  ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE orderitems (
  id int(11) NOT NULL auto_increment,
  orderid int(11) NOT NULL default '0',
  productid int(11) NOT NULL default '0',
  quantity int(11) NOT NULL default '1',
  unitprice float NOT NULL default '0',
  taxrate float NOT NULL default '0',
  PRIMARY KEY(id,orderid),
  CONSTRAINT orderitems_order_fk FOREIGN KEY(orderid) REFERENCES orders(id)
  ON UPDATE CASCADE
  ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE orderstatus (
  id int(11) NOT NULL auto_increment,
  name char(32) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE cardpayment (
  id int(11) NOT NULL auto_increment,
  orderid int(11) NOT NULL default '0',
  typeid tinyint(4) NOT NULL default '0',
  bank varchar(64) NOT NULL default '',
  cardnumber varchar(22) NOT NULL default '',
  expdate varchar(8) NOT NULL default '',
  extranumber varchar(16) NOT NULL default '',
  issuenum int(11) NOT NULL default '0',
  nameoncard varchar(64) NOT NULL default '',
  referencenum varchar(64) NOT NULL default '',
  PRIMARY KEY(id,orderid),
  CONSTRAINT cardpayment_order_fk FOREIGN KEY(orderid) REFERENCES orders(id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE paygrades (
  id int(11) NOT NULL auto_increment,
  name char(16) NOT NULL default '',
  numincrements int(11) NOT NULL default '0',
  minimum float(6,2) NOT NULL default '0.00',
  maximum float(6,2) NOT NULL default '0.00',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE paymentdetails (
  id int(11) NOT NULL auto_increment,
  reference varchar(64) NOT NULL default '',
  extradata varchar(128) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE paymentitem (
  id int(11) NOT NULL auto_increment,
  payid int(10) unsigned NOT NULL default '0',
  transid int(10) unsigned NOT NULL default '0',
  paytype tinyint(4) NOT NULL default '1',
  amount double NOT NULL default '0',
  enteredat timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  enteredby int(11) NOT NULL default '0',
  enteredstation char(20) NOT NULL default '',
  paymentdetailsid int(11) NOT NULL default '1',
  PRIMARY KEY(id,payid,transid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE paymentterms (
  id int(11) NOT NULL auto_increment,
  name char(32) NOT NULL default '',
  days int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE paymenttype (
  id int(11) NOT NULL auto_increment,
  groupptrid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  cashback char(1) NOT NULL default 'N',
  cashbacklimit float NOT NULL default '0',
  bacceptable char(1) NOT NULL default 'Y',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE paylog (
  id int(11) NOT NULL auto_increment,
  typeid int(11) NOT NULL default '0',
  datedone date NOT NULL default '0000-00-00',
  amount float NOT NULL,
  PRIMARY KEY (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE paytype (
  id int(11) NOT NULL auto_increment,
  name varchar(32) NOT NULL default '',
  timevalue float NOT NULL default '1.0',
  PRIMARY KEY (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE period (
  id int(11) NOT NULL auto_increment,
  `start` date NOT NULL default '0000-00-00',
  `end` date NOT NULL default '0000-00-00',
  description varchar(64) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE plu_cache (
  id int(11) NOT NULL auto_increment,
  productid int(11) NOT NULL default '0',
  nameid int(11) NOT NULL default '1',
  plu varchar(16) NOT NULL default '',
  disptext varchar(64) NOT NULL default '',
  recutext varchar(32) NOT NULL default '',
  unitprice float NOT NULL default '0',
  discount float NOT NULL default '0',
  deposittype int(11) NOT NULL default '0',
  deposit float NOT NULL default '0',
  tax float NOT NULL default '0',
  itemflags int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE postaction (
  id int(4) NOT NULL auto_increment,
  `action` varchar(32) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE postinterface (
  id int(11) NOT NULL auto_increment,
  postid int(11) NOT NULL default '0',
  interfaceid int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE posts (
  id int(11) NOT NULL auto_increment,
  name varchar(32) NOT NULL default '',
  mac varchar(12) NOT NULL default '0',
  groupid int(11) NOT NULL default '0',
  localeid int(4) NOT NULL default '270',
  currencyid int(4) NOT NULL default '270',
  active char(1) NOT NULL default 'N',
  PRIMARY KEY(id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE postlog (
  id int(11) NOT NULL auto_increment,
  postid int(11) NOT NULL default '0',
  actionid int(4) NOT NULL default '0',
  stamper timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  `data` varchar(32) NOT NULL default '',
  PRIMARY KEY(id,postid),
  CONSTRAINT postlog_post_fk FOREIGN KEY(postid) REFERENCES posts(id)
  ON UPDATE CASCADE
  ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE printer (
  id int(11) NOT NULL auto_increment,
  name varchar(32) NOT NULL default '',
  description varchar(64) NOT NULL default '',
  address varchar(128) NOT NULL default '',
  port varchar(5) NOT NULL default '',
  active char(1) NOT NULL default 'N',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE printform (
  id int(11) NOT NULL auto_increment,
  name varchar(32) NOT NULL default '',
  description varchar(64) NOT NULL default '',
  printerid int(11) NOT NULL default '0',
  sheetid int(11) NOT NULL default '0',
  orientation char(1) NOT NULL default '',
  printitemid int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE printitem (
  id int(11) NOT NULL auto_increment,
  printitemid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  x int(11) NOT NULL default '0',
  y int(11) NOT NULL default '0',
  xsize int(11) NOT NULL default '0',
  ysize int(11) NOT NULL default '0',
  `fixed` char(1) NOT NULL default 'N',
  content varchar(255) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE printsheet (
  id int(11) NOT NULL auto_increment,
  name varchar(32) NOT NULL default '',
  xsize int(11) NOT NULL default '0',
  ysize int(11) NOT NULL default '0',
  left_margin int(11) NOT NULL default '0',
  right_margin int(11) NOT NULL default '0',
  top_margin int(11) NOT NULL default '0',
  bottom_margin int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;


-- --------------------------------------------------------

CREATE TABLE pqname (
  id int(11) NOT NULL auto_increment,
  name varchar(64) NOT NULL default '',
  accountid int(11) NOT NULL default '0',
  onmenu char(1) NOT NULL default 'N',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE prodpricequantity (
  id int(11) NOT NULL auto_increment,
  pqid mediumint(9) NOT NULL default '0',
  nameid int(11) NOT NULL default '1',
  quantity int(11) NOT NULL default '1',
  quantitytypeid int(11) NOT NULL default '0',
  udv int(11) NOT NULL default '1',
  price double(14,4) NOT NULL default '0.0000',
  basecurrencyid mediumint(9) NOT NULL default '0',
  taxid int(4) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE prodsearchcache (
  word text NOT NULL,
  productid int(11) NOT NULL default '0',
  FULLTEXT KEY `index` (word)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

CREATE TABLE prodtarget (
  id int(11) NOT NULL auto_increment,
  cmid int(11) NOT NULL default '0',
  productid int(11) NOT NULL default '0',
  periodtype int(1) NOT NULL default '0',
  period int(11) NOT NULL default '0',
  targettype int(1) NOT NULL default '0',
  target varchar(16) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE product (
  id int(11) NOT NULL auto_increment,
  productid int(10) unsigned NOT NULL default '0',
  invid int(11) NOT NULL default '0',
  attributeid int(11) NOT NULL default '0',
  categoryid mediumint(9) NOT NULL default '0',
  accountid int(11) NOT NULL default '0',
  plu varchar(128) NOT NULL default '',
  plutype int(2) NOT NULL default '0',
  name varchar(64) NOT NULL default 'No Name',
  description varchar(128) NOT NULL default 'No Description',
  instock int(11) NOT NULL default '0',
  discontinued char(1) NOT NULL default 'N',
  imageid int(11) NOT NULL default '0',
  reciepttext varchar(64) NOT NULL default 'No Name',
  labelid int(11) NOT NULL default '0',
  sellquantityid int(11) NOT NULL default '0',
  discountid int(11) NOT NULL default '0',
  promotionid int(11) NOT NULL default '1',
  rentable char(1) NOT NULL default 'N',
  depositid int(11) NOT NULL default '0',
  ecommerce char(1) NOT NULL default 'N',
  flags int(11) unsigned NOT NULL default '0',
  productlink int(11) NOT NULL default '0',
  keywords varchar(255) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE productattribute (
  id int(11) NOT NULL auto_increment,
  attributeid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  `type` int(2) NOT NULL default '0',
  format varchar(255) NOT NULL default '',
  mask varchar(255) NOT NULL default '',
  `value` varchar(255) NOT NULL default '',
  PRIMARY KEY  (id),
  KEY attributeid (attributeid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE productcategory (
  productid int(11) NOT NULL default '0',
  categoryid int(11) NOT NULL default '0'
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE productcollection (
  prodcollid int(11) NOT NULL default '0',
  productid int(11) NOT NULL default '0'
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE productserialnumber (
  id int(11) NOT NULL auto_increment,
  serialnumber varchar(64) NOT NULL default '',
  orderid int(11) NOT NULL default '0',
  productid int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE productsplit (
  id int(11) NOT NULL auto_increment,
  prodsplitid int(11) NOT NULL default '0',
  qtyid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  description varchar(255) NOT NULL default '',
  productid int(11) NOT NULL default '0',
  PRIMARY KEY(id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE productsplitqty (
  id int(11) NOT NULL auto_increment,
  qtyid int(11) NOT NULL default '0',
  productid int(11) NOT NULL default '0',
  `value` double NOT NULL default '0',
  valuetype char(1) NOT NULL default '',
  PRIMARY KEY(id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE catalogue (
  id int(11) NOT NULL auto_increment,
  productcollectionid int(11) NOT NULL default '0',
  name varchar(64) NOT NULL default '',
  description varchar(255) NOT NULL default '',
  type char(1) NOT NULL default 'C',
  discounttype char(1) NOT NULL default 'D',
  discountid int(11) NOT NULL default '0',
  PRIMARY KEY(id,productcollectionid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE promotion (
  id int(11) NOT NULL auto_increment,
  promotionid int(11) NOT NULL default '0',
  typeid int(1) NOT NULL default '0',
  name varchar(64) NOT NULL default '',
  startdate date NOT NULL default '0000-00-00',
  enddate date NOT NULL default '0000-00-00',
  targetid int(11) NOT NULL default '0',
  promolinkid int(11) NOT NULL default '0',
  PRIMARY KEY(id,promotionid,typeid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE purchaseorder (
  id int(11) NOT NULL auto_increment,
  purchaseorderid int(12) unsigned NOT NULL default '0',
  purchasenumber varchar(64) NOT NULL default '',
  statusid int(11) NOT NULL default '0',
  name varchar(64) NOT NULL default '',
  cmid int(11) NOT NULL default '0',
  generatedat int(11) NOT NULL default '0',
  placeddate date NOT NULL default '0000-00-00',
  dispatchdate date NOT NULL default '0000-00-00',
  arriveddate date NOT NULL default '0000-00-00',
  supplierid int(11) NOT NULL default '0',
  deliverto int(11) NOT NULL default '0',
  shippingid int(11) NOT NULL default '0',
  requestedby int(11) NOT NULL default '0',
  approvedby int(11) NOT NULL default '0',
  ledgerentryid int(11) NOT NULL default '0',
  transactionid int(11) NOT NULL default '0',
  linkid int(11) NOT NULL default '0',
  PRIMARY KEY(id,purchaseorderid),
  INDEX(ledgerentryid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE purchaseorderitems (
  id int(11) NOT NULL auto_increment,
  purchaseorderid int(11) NOT NULL default '0',
  quantity int(11) NOT NULL default '1',
  inventoryid int(11) NOT NULL default '0',
  `status` tinyint(4) NOT NULL default '0',
  PRIMARY KEY(id,purchaseorderid),
  CONSTRAINT purchaseorderitems_po_fk FOREIGN KEY(purchaseorderid) REFERENCES purchaseorder(id)
  ON UPDATE CASCADE
  ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE `purchasestatus` (
  id INT NOT NULL AUTO_INCREMENT,
  name VARCHAR(32) NOT NULL,
  PRIMARY KEY(id)
) TYPE = InnoDB;

-- --------------------------------------------------------

-- 
-- Table structure for table `rec_stock`
-- 

CREATE TABLE rec_stock (
  id int(11) NOT NULL auto_increment,
  invid int(11) NOT NULL default '0',
  plu varchar(16) NOT NULL default '',
  sold int(11) NOT NULL default '0',
  returned int(11) NOT NULL default '0',
  recieved int(11) NOT NULL default '0',
  transferin int(11) NOT NULL default '0',
  transferout int(11) NOT NULL default '0',
  out int(11) NOT NULL default '0',
  stocklevelwarning int(11) NOT NULL default '0',
  PRIMARY KEY  (id),
  UNIQUE KEY PLU (plu)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- --------------------------------------------------------

-- 
-- Table structure for table `rental`
-- 

CREATE TABLE rental (
  id int(11) NOT NULL auto_increment,
  transactionid int(11) NOT NULL default '0',
  customerid int(11) NOT NULL default '0',
  rentedfromid int(11) NOT NULL default '0',
  rentedon timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  duration int(11) NOT NULL default '0',
  returned char(1) NOT NULL default 'N',
  returnedtoid int(11) NOT NULL default '0',
  returnedat timestamp NOT NULL default '0000-00-00 00:00:00',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE rentalitems (
  id int(11) NOT NULL auto_increment,
  rentalid int(11) NOT NULL default '0',
  productid int(11) NOT NULL default '0',
  quantity int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- --------------------------------------------------------

-- 
-- Table structure for table `reservation`
-- 

CREATE TABLE reservation (
  id int(11) NOT NULL auto_increment,
  reservationid int(11) NOT NULL default '0',
  cmid int(11) NOT NULL default '0',
  memberid int(11) NOT NULL default '0',
  sdate date NOT NULL default '0000-00-00',
  edate date NOT NULL default '0000-00-00',
  opendate date NOT NULL default '0000-00-00',
  closedate date NOT NULL default '0000-00-00',
  `type` int(11) NOT NULL default '0',
  notes varchar(64) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE reservationref (
  refid int(11) NOT NULL default '0',
  reservationid int(11) NOT NULL default '0'
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE reservationtype (
  id int(11) NOT NULL auto_increment,
  name varchar(64) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- --------------------------------------------------------

-- 
-- Table structure for table `return`
-- 

CREATE TABLE return (
  id int(11) NOT NULL auto_increment,
  transid int(11) NOT NULL default '0',
  `type` int(1) NOT NULL default '0',
  destination int(1) NOT NULL default '0',
  todestat timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  todestby int(11) NOT NULL default '0',
  reasonid smallint(6) NOT NULL default '0',
  PRIMARY KEY(id, transid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- --------------------------------------------------------

-- 
-- Table structure for table `returnreason`
-- 

CREATE TABLE returnreason (
  id int(11) NOT NULL auto_increment,
  transid int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- --------------------------------------------------------

-- 
-- Table structure for table `returntype`
-- 

CREATE TABLE returntype (
  id int(11) NOT NULL auto_increment,
  name varchar(64) NOT NULL default '',
  active char(1) NOT NULL default 'N',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- --------------------------------------------------------

-- 
-- Table structure for table `roster`
-- 

CREATE TABLE roster (
  id int(11) NOT NULL auto_increment,
  rosterid int(11) NOT NULL default '0',
  cmid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  rosterentryid int(11) NOT NULL default '0',
  active char(1) NOT NULL default 'N',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- --------------------------------------------------------

-- 
-- Table structure for table `rosterentry`
-- 

CREATE TABLE rosterentry (
  id int(11) NOT NULL auto_increment,
  rosterentryid int(11) NOT NULL default '0',
  `day` tinyint(4) NOT NULL default '0',
  `month` tinyint(4) NOT NULL default '0',
  starttime time NOT NULL default '00:00:00',
  endtime time NOT NULL default '00:00:00',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- --------------------------------------------------------

-- 
-- Table structure for table `rosteritem`
-- 

CREATE TABLE rosteritem (
  id int(11) NOT NULL auto_increment,
  employeeid int(11) NOT NULL default '0',
  rosterid int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE salesarea (
  id int(11) NOT NULL auto_increment,
  areacode varchar(8) NOT NULL default '',
  areaname varchar(64) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- --------------------------------------------------------

-- 
-- Table structure for table `salesperson`
-- 

CREATE TABLE salesperson (
  id int(11) NOT NULL auto_increment,
  employeeid int(11) NOT NULL default '0',
  areaid int(11) NOT NULL default '0',
  commissionid int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- --------------------------------------------------------

-- 
-- Table structure for table `schedule`
-- 

CREATE TABLE schedule (
  id int(11) NOT NULL auto_increment,
  cmid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  `month` tinyint(2) NOT NULL default '0',
  dayofweek tinyint(1) NOT NULL default '0',
  `day` tinyint(2) NOT NULL default '0',
  `hour` tinyint(2) NOT NULL default '0',
  `minute` tinyint(2) NOT NULL default '0',
  oneshot char(1) NOT NULL default 'N',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- --------------------------------------------------------

-- 
-- Table structure for table `servicecontract`
-- 

CREATE TABLE servicecontract (
  id int(11) NOT NULL auto_increment,
  custid int(11) NOT NULL default '0',
  typeid int(11) NOT NULL default '0',
  startdate date NOT NULL default '0000-00-00',
  enddate date NOT NULL default '0000-00-00',
  price float(6,2) NOT NULL default '0.00',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE setup (
  id int(4) NOT NULL default '0',
  name varchar(255) NOT NULL default '"No Name"',
  cmid int(11) NOT NULL default '0',
  siteid int(11) NOT NULL default '0',
  ismaster char(1) NOT NULL default 'N',
  `master` varchar(64) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;


-- 
-- Shipping
-- 

CREATE TABLE shipcarrier (
  id int(11) NOT NULL auto_increment,
  name varchar(32) NOT NULL default '',
  enabled char(1) NOT NULL default 'N',
  updatesite varchar(128) NOT NULL default '',
  autoupdate char(1) NOT NULL default 'N',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE shipratename (
  id INT NOT NULL AUTO_INCREMENT ,
  name VARCHAR(32) NOT NULL ,
  carriervalue VARCHAR(16) NOT NULL ,
  PRIMARY KEY (id)
)ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE shipping (
  id int(11) NOT NULL auto_increment,
  name varchar(64) NOT NULL default '',
  eshipid int(6) NOT NULL default '0',
  rate float NOT NULL default '0',
  tax float NOT NULL default '0',
  `value` float NOT NULL default '0',
  trackingnum varchar(32) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE shiprate (
  id int(11) NOT NULL auto_increment,
  nameid int(11) NOT NULL default '0',
  weightid int(11) NOT NULL default '0',
  volumeid int(11) NOT NULL default '0',
  maxvalue float NOT NULL default '0',
  deliverytime varchar(32) NOT NULL default '',
  enabled char(1) NOT NULL default 'N',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE shipvolume (
  id int(11) NOT NULL auto_increment,
  unitname varchar(32) NOT NULL default '',
  length float NOT NULL default '0',
  width float NOT NULL default '0',
  height float NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE shipweight (
  id int(11) NOT NULL auto_increment,
  unitname varchar(32) NOT NULL default '',
  lowerbound double NOT NULL default '0',
  upperbound double NOT NULL default '0',
  unitrate double NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- --------------------------------------------------------

-- 
-- Table structure for table `signature`
-- 

CREATE TABLE signature (
  id int(11) NOT NULL auto_increment,
  signatureid int(11) NOT NULL default '0',
  cmid int(11) NOT NULL default '0',
  category varchar(32) NOT NULL default '',
  xdim int(11) NOT NULL default '0',
  ydim int(11) NOT NULL default '0',
  typeid int(11) NOT NULL default '0',
  fileref varchar(255) NOT NULL default '',
  validuntil date NOT NULL default '0000-00-00',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- --------------------------------------------------------

-- 
-- Table structure for table `signaturerefcount`
-- 

CREATE TABLE signaturerefcount (
  id int(11) NOT NULL auto_increment,
  signatureid int(11) NOT NULL default '0',
  signedat timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- --------------------------------------------------------

-- 
-- Table structure for table `signaturetype`
-- 

CREATE TABLE signaturetype (
  id int(11) NOT NULL auto_increment,
  typeid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE `status` (
  id int(11) NOT NULL auto_increment,
  name char(32) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;


CREATE TABLE storecard (
  id int(11) NOT NULL auto_increment,
  cardid varchar(16) NOT NULL default '',
  custid int(11) NOT NULL default '0',
  discountid int(11) NOT NULL default '0',
  barcode varchar(128) NOT NULL default '0',
  swipedata varchar(128) NOT NULL default '0',
  writable char(1) NOT NULL default 'N',
  amcurrent double NOT NULL default '0',
  amlimit double NOT NULL default '0',
  `status` int(1) NOT NULL default '0',
  memoid int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;


CREATE TABLE subscription (
  id int(11) NOT NULL auto_increment,
  subscriptionid int(11) NOT NULL default '0',
  customerid int(11) NOT NULL default '0',
  tagline varchar(128) NOT NULL default '',
  contentid int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;


CREATE TABLE supplier (
  id int(11) NOT NULL auto_increment,
  supplierid int(11) NOT NULL default '0',
  intsupplierid varchar(32) NOT NULL default '',
  cmid int(11) NOT NULL default '0',
  name varchar(64) NOT NULL default '',
  addressid int(11) NOT NULL default '0',
  contactid int(11) NOT NULL default '0',
  invoicename varchar(64) NOT NULL default '',
  invoicecontactid int(11) NOT NULL default '0',
  chargeid int(11) NOT NULL default '0',
  ediid int(11) NOT NULL default '0',
  linkid int(11) NOT NULL default '0',
  active char(1) NOT NULL default 'N',
  memoid int(11) NOT NULL default '0',
  PRIMARY KEY(id,supplierid),
  INDEX(addressid),
  INDEX(contactid),
  INDEX(chargeid),
  CONSTRAINT supplier_address_fk FOREIGN KEY(addressid) REFERENCES address(id),
  CONSTRAINT supplier_contact_fk FOREIGN KEY(contactid) REFERENCES contacts(id),
  CONSTRAINT supplier_charge_fk FOREIGN KEY(chargeid) REFERENCES chargeaccount(id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;


CREATE TABLE synch (
  id int(11) NOT NULL auto_increment,
  typeid int(11) NOT NULL default '0',
  creationdate timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  modifieddate timestamp NOT NULL default '0000-00-00 00:00:00',
  implementationat timestamp NOT NULL default '0000-00-00 00:00:00',
  implemented char(1) NOT NULL default 'N',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE synchtype (
  id int(11) NOT NULL auto_increment,
  name char(32) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE systemattribute (
  id int(11) NOT NULL auto_increment,
  attributeid int(11) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  `type` int(2) NOT NULL default '0',
  format varchar(255) NOT NULL default '',
  mask varchar(255) NOT NULL default '',
  `value` varchar(255) NOT NULL default '',
  PRIMARY KEY  (id),
  KEY attributeid (attributeid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE tabler (
  id int(11) NOT NULL auto_increment,
  areaid tinyint(4) NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  description varchar(64) NOT NULL default '',
  capacity int(4) NOT NULL default '0',
  notes varchar(255) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE taxrate (
  id int(11) NOT NULL auto_increment,
  taxid mediumint(9) NOT NULL default '0',
  accountid int(11) NOT NULL default '0',
  rate float(7,5) NOT NULL default '0.00000',
  onmenu char(1) NOT NULL default 'N',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;


CREATE TABLE title (
  id tinyint(4) NOT NULL auto_increment,
  name varchar(32) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE `transaction` (
  id int(11) NOT NULL auto_increment,
  transactionid int(12) unsigned NOT NULL default '0',
  enteredat timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  enteredby int(11) NOT NULL default '0',
  enteredstation varchar(20) NOT NULL default '',
  statusid int(4) NOT NULL default '15',
  paymenttypeid int(11) NOT NULL default '0',
  refnum varchar(32) NOT NULL default '',
  description varchar(64) NOT NULL default '',
  `open` char(1) NOT NULL default 'Y',
  reconciled char(1) NOT NULL default 'N',
  taxable char(1) NOT NULL default 'Y',
  settlementid int(10) unsigned NOT NULL default '0',
  linkid int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (id),
  KEY transidx (transactionid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE transactionitems (
  id int(11) NOT NULL auto_increment,
  transactionid int(11) NOT NULL default '0',
  enteredat timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  enteredby int(11) NOT NULL default '0',
  enteredstation varchar(20) NOT NULL default '',
  `type` int(4) NOT NULL default '2',
  plu varchar(132) NOT NULL default '0000000000000',
  quantity int(11) NOT NULL default '1',
  PRIMARY KEY(id, transactionid),
  KEY pluidx(plu)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE transtype (
  id int(11) NOT NULL auto_increment,
  transid int(11) NOT NULL default '0',
  `type` int(1) NOT NULL default '0',
  `data` varchar(32) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE u_plu (
  id int(11) NOT NULL auto_increment,
  entryat timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  plu varchar(128) NOT NULL default '',
  plutype int(1) NOT NULL default '0',
  name varchar(64) NOT NULL default 'No Name',
  unitprice double NOT NULL default '0',
  discount float NOT NULL default '0',
  tax float NOT NULL default '0',
  PRIMARY KEY  (id),
  UNIQUE KEY PLU (plu)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE userauth (
  id int(11) NOT NULL auto_increment,
  userid int(11) NOT NULL default '0',
  authid int(11) NOT NULL default '1',
  interfaceid int(11) NOT NULL default '0',
  groupid int(11) NOT NULL default '0',
  loginmethodid int(11) NOT NULL default '0',
  PRIMARY KEY(id),
  INDEX(userid)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE users (
  id int(11) NOT NULL auto_increment,
  login varchar(16) NOT NULL default '',
  `password` varchar(16) NOT NULL default '',
  userdata varchar(255) NOT NULL default '',
  profile varchar(255) NOT NULL default '',
  logintypesid int(4) NOT NULL default '0',
  employeeid int(11) NOT NULL default '0',
  PRIMARY KEY(id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE voucher (
  id int(11) NOT NULL auto_increment,
  voucherid varchar(16) NOT NULL default '',
  plu varchar(128) NOT NULL default '',
  enddate date NOT NULL default '0000-00-00',
  used char(1) NOT NULL default 'N',
  `type` int(1) NOT NULL default '0',
  margin double NOT NULL default '0',
  productlinkid int(11) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
